==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/QGpCoreTools/src/QGpCoreTools.h <==
#ifndef QGPCORETOOLS_HEADERS
#define QGPCORETOOLS_HEADERS

// All headers of QGpCoreTools library

#include "AbstractParameters.h"
#include "AbstractProgress.h"
#include "AbstractStream.h"
#include "AbstractTask.h"
#include "ApplicationClock.h"
#include "ApplicationHelp.h"
#include "ArgumentStdinReader.h"
#include "AsciiLineParser.h"
#include "AtomicBoolean.h"
#include "Cache.h"
#include "CacheItem.h"
#include "CacheProcess.h"
#include "Color.h"
#include "ColumnTextDescription.h"
#include "ColumnTextFile.h"
#include "ColumnTextIterator.h"
#include "ColumnTextParser.h"
#include "Complex.h"
#include "ComplexMP.h"
#include "ConsoleProgress.h"
#include "CoreApplication.h"
#include "CoreApplicationPrivate.h"
#include "DateTime.h"
#include "DynamicBuffer.h"
#include "EventRestrictor.h"
#include "ExpressionAction.h"
#include "ExpressionActions.h"
#include "ExpressionContext.h"
#include "ExpressionParser.h"
#include "ExpressionStorage.h"
#include "ExpressionString.h"
#include "File.h"
#include "FileStream.h"
#include "FletcherChecksum.h"
#include "Global.h"
#include "IncreaseStorage.h"
#include "Leds.h"
#include "LineParser.h"
#include "LocalPointer.h"
#include "MemoryChecker.h"
#include "Message.h"
#include "MessageContext.h"
#include "Mutex.h"
#include "Number.h"
#include "PackageInfo.h"
#include "ParallelLoop.h"
#include "PathTranslator.h"
#include "PathTranslatorOptions.h"
#include "PluginCoreApplication.h"
#include "PluginSettings.h"
#include "QGpCoreToolsDLLExport.h"
#include "ReadWriteLock.h"
#include "RealMP.h"
#include "ScriptContext.h"
#include "SharedObject.h"
#include "SortedStringList.h"
#include "SortedVector.h"
#include "StandardStream.h"
#include "StreamRedirection.h"
#include "StringSection.h"
#include "StringStream.h"
#include "Tar.h"
#include "TaskManager.h"
#include "TaskWorker.h"
#include "Thread.h"
#include "ThreadTimer.h"
#include "Trace.h"
#include "TraceBug.h"
#include "TraceInfo.h"
#include "TraceLog.h"
#include "TraceStamp.h"
#include "TreeContainer.h"
#include "TreeItem.h"
#include "UniqueID.h"
#include "Version.h"
#include "XMLByteArrayStream.h"
#include "XMLClass.h"
#include "XMLClassFactory.h"
#include "XMLContext.h"
#include "XMLErrorReport.h"
#include "XMLGenericItem.h"
#include "XMLHeader.h"
#include "XMLMap.h"
#include "XMLMember.h"
#include "XMLSaveAttributes.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreTools;
#endif

#endif // QGPCORETOOLS_HEADERS

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpCoreTools/src/QGpCoreTools.h <==
#ifndef QGPCORETOOLS_HEADERS
#define QGPCORETOOLS_HEADERS

// All headers of QGpCoreTools library

#include "AbstractParameters.h"
#include "AbstractProgress.h"
#include "AbstractStream.h"
#include "ApplicationClock.h"
#include "ApplicationHelp.h"
#include "ArgumentStdinReader.h"
#include "AsciiLineParser.h"
#include "AtomicBoolean.h"
#include "Cache.h"
#include "CacheItem.h"
#include "CacheProcess.h"
#include "Color.h"
#include "ColumnTextDescription.h"
#include "ColumnTextFile.h"
#include "ColumnTextIterator.h"
#include "ColumnTextParser.h"
#include "Complex.h"
#include "ComplexMP.h"
#include "ConsoleProgress.h"
#include "CoreApplication.h"
#include "CoreApplicationPrivate.h"
#include "DateTime.h"
#include "DynamicBuffer.h"
#include "EventRestrictor.h"
#include "ExpressionAction.h"
#include "ExpressionActions.h"
#include "ExpressionContext.h"
#include "ExpressionParser.h"
#include "ExpressionStorage.h"
#include "ExpressionString.h"
#include "File.h"
#include "FileStream.h"
#include "FletcherChecksum.h"
#include "Global.h"
#include "IncreaseStorage.h"
#include "Leds.h"
#include "LineParser.h"
#include "LocalPointer.h"
#include "MemoryChecker.h"
#include "Message.h"
#include "MessageContext.h"
#include "Mutex.h"
#include "Number.h"
#include "PackageInfo.h"
#include "ParallelLoop.h"
#include "ParallelTask.h"
#include "ParallelTaskManager.h"
#include "ParallelTaskWorker.h"
#include "PathTranslator.h"
#include "PathTranslatorOptions.h"
#include "PluginCoreApplication.h"
#include "PluginSettings.h"
#include "QGpCoreToolsDLLExport.h"
#include "ReadWriteLock.h"
#include "RealMP.h"
#include "ScriptContext.h"
#include "SharedObject.h"
#include "SortedStringList.h"
#include "SortedVector.h"
#include "StandardStream.h"
#include "StreamRedirection.h"
#include "StringSection.h"
#include "StringStream.h"
#include "Tar.h"
#include "Thread.h"
#include "ThreadTimer.h"
#include "Trace.h"
#include "TraceBug.h"
#include "TraceInfo.h"
#include "TraceLog.h"
#include "TraceStamp.h"
#include "TreeContainer.h"
#include "TreeItem.h"
#include "UniqueID.h"
#include "Version.h"
#include "XMLByteArrayStream.h"
#include "XMLClass.h"
#include "XMLClassFactory.h"
#include "XMLContext.h"
#include "XMLErrorReport.h"
#include "XMLGenericItem.h"
#include "XMLHeader.h"
#include "XMLMap.h"
#include "XMLMember.h"
#include "XMLSaveAttributes.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreTools;
#endif

#endif // QGPCORETOOLS_HEADERS
